# Boltz Python Client
Boltz Reference Client in Python, used by e.g. https://github.com/lnbits/boltz

## installing
```console
poetry install
```

## running cli
```console
poetry run boltz
```

## starting regtest
```console
cd docker
chmod +x regtest
./regtest
```

## running tests
```console
poetry run pytest
```

Or install the latest release from [PyPI](https://pypi.org/project/boltz-client) via `pip install boltz-client`.
